<?php

namespace Drupal\media_remote_embed\Plugin\Field\FieldWidget;

use Drupal\media\MediaTypeInterface;
use Drupal\media_link\Plugin\Field\FieldWidget\OEmbedLinkMediaWidget;
use Drupal\media_remote_embed\Plugin\media\Source\RemoteEmbed;
use Drupal\media_remote_embed\Provider\ProviderFactory;

/**
 * Extends the link media widget to support remote embeds.
 */
class RemoteEmbedLinkMediaWidget extends OEmbedLinkMediaWidget {

  /**
   * {@inheritdoc}
   */
  protected static function isSupportedMediaType(MediaTypeInterface $media_type): bool {
    return parent::isSupportedMediaType($media_type) || static::isRemoteEmbedMediaType($media_type);
  }

  /**
   * Returns the provider factory.
   *
   * @return \Drupal\media_remote_embed\Provider\ProviderFactory
   *   The provider factory.
   */
  protected static function getProviderFactory(): ProviderFactory {
    return \Drupal::service('media_remote_embed.provider_factory');
  }

  /**
   * {@inheritdoc}
   */
  protected static function getMediaTypeFromUrl(string $url, array $media_types): MediaTypeInterface {
    $providers = static::getProviderFactory()
      ->getAll();

    foreach ($providers as $provider) {
      if (!$provider->isApplicable($url)) {
        continue;
      }
      foreach ($media_types as $media_type) {
        if (static::isRemoteEmbedMediaType($media_type)) {
          return $media_type;
        }
      }
    }
    return parent::getMediaTypeFromUrl($url, $media_types);
  }

  /**
   * Checks whether the specified media type is a remote embed one.
   *
   * @param \Drupal\media\MediaTypeInterface $media_type
   *   A media type entity.
   *
   * @return bool
   *   TRUE if this is a Link media type, FALSE otherwise.
   */
  protected static function isRemoteEmbedMediaType(MediaTypeInterface $media_type): bool {
    return $media_type->getSource() instanceof RemoteEmbed;
  }

}
