<?php

namespace Drupal\media_remote_embed\Provider;

/**
 * Common interface for Providers.
 */
interface ProviderInterface {

  /**
   * Returns the provider ID.
   *
   * @return string
   *   A machine name.
   */
  public function id(): string;

  /**
   * A check to identify if this provider should be used for a specific URI.
   *
   * @param string $embed_uri
   *   URL added to the media widget by user.
   *
   * @return mixed
   *   False if not the correct provider or a truthy value.
   */
  public function isApplicable(string $embed_uri);

  /**
   * Builds and returns render array for the embed.
   *
   * @param array $settings
   *   Formatter settings including URI, height, width.
   *
   * @return array
   *   Render array containing markup needed for embed.
   */
  public function getEmbedMarkup(array $settings): array;

}
